@@ -29,7 +29,7 @@ namespace LongoMatch.Common
 
 		public static CaptureSettings DefaultSettings() {
 			CaptureSettings settings = new CaptureSettings();
-			settings.CaptureSourceType = CaptureSourceType.Raw;
+			settings.CaptureSourceType = CaptureSourceType.System;
 			settings.EncodingSettings = new EncodingSettings(VideoStandards.P480_4_3,
 			                                                 EncodingProfiles.MP4,
 			                                                 25, 1, 1000, 128, "", 20);
